@@ -81,6 +81,8 @@ class GSPDataSource(ImageDataSource):
         """
         # load metadata
         self.metadata = get_gsp_metadata_from_eso()
+        self.metadata.set_index("gsp_id", drop=False, inplace=True)
+        self.metadata.index.name = ""
 
         # make location x,y in osgb
         self.metadata["location_x"], self.metadata["location_y"] = lat_lon_to_osgb(
@@ -212,8 +214,9 @@ class GSPDataSource(ImageDataSource):
         selected_gsp_power = selected_gsp_power[all_gsp_ids]
         selected_capacity = selected_capacity[all_gsp_ids]
 
-        gsp_x_coords = self.metadata[self.metadata["gsp_id"].isin(all_gsp_ids)].location_x
-        gsp_y_coords = self.metadata[self.metadata["gsp_id"].isin(all_gsp_ids)].location_y
+        # get x,y coordinates
+        gsp_x_coords = self.metadata.location_x[all_gsp_ids]
+        gsp_y_coords = self.metadata.location_y[all_gsp_ids]
 
         # convert to data array
         da = xr.DataArray(
@@ -325,7 +328,7 @@ class GSPDataSource(ImageDataSource):
 
         Returns: list of GSP ids that are in area of interest
         """
-        logger.debug("Getting all gsp in ROI")
+        logger.debug(f"Getting all gsp in ROI ({x_meters_center=},{y_meters_center=})")
 
         # creating bounding box
         bounding_box = self._square.bounding_box_centered_on(
