@@ -4,6 +4,7 @@ from dataclasses import InitVar, dataclass
 from numbers import Number
 from typing import Iterable, Optional
 
+import dask
 import numpy as np
 import pandas as pd
 import xarray as xr
@@ -207,7 +208,7 @@ class HRVSatelliteDataSource(SatelliteDataSource):
     meters_per_pixel: InitVar[int] = 2_000
 
 
-def remove_acq_time_from_dataset(dataset: xr.Dataset) -> xr.Dataset:
+def remove_acq_time_from_dataset_and_fix_time_coords(dataset: xr.Dataset) -> xr.Dataset:
     """
     Preprocess datasets by dropping `acq_time`, which causes problems otherwise
 
@@ -218,6 +219,31 @@ def remove_acq_time_from_dataset(dataset: xr.Dataset) -> xr.Dataset:
         dataset with acq_time dropped
     """
     dataset = dataset.drop_vars("acq_time", errors="ignore")
+
+    # If there are any duplicated init_times then drop the duplicated init_times:
+    data_array = dataset["stacked_eumetsat_data"]
+    times = pd.DatetimeIndex(data_array["time"])
+    if not times.is_unique:
+        n_duplicates = times.duplicated().sum()
+        _LOG.warning(f"Satellite Zarr has {n_duplicates:,d} duplicated times.  Fixing...")
+        data_array = data_array.drop_duplicates(dim="time")
+        times = pd.DatetimeIndex(data_array["time"])
+        dataset = data_array.to_dataset(name="stacked_eumetsat_data")
+
+    # If any init_times are not monotonic_increasing then drop the out-of-order init_times:
+    if not times.is_monotonic_increasing:
+        total_n_out_of_order_times = 0
+        _LOG.warning("Satellite Zarr times is not monotonic_increasing.  Fixing...")
+        while not times.is_monotonic_increasing:
+            diff = np.diff(times.view(int))
+            out_of_order = np.where(diff < 0)[0]
+            total_n_out_of_order_times += len(out_of_order)
+            out_of_order = times[out_of_order]
+            data_array = data_array.drop_sel(time=out_of_order)
+            times = pd.DatetimeIndex(data_array["init_time"])
+        _LOG.info(f"Fixed {total_n_out_of_order_times:,d} out of order init_times.")
+        dataset = data_array.to_dataset(name="stacked_eumetsat_data")
+
     return dataset
 
 
@@ -236,44 +262,32 @@ def open_sat_data(zarr_path: str, consolidated: bool) -> xr.DataArray:
     # If we are opening multiple Zarr stores (i.e. one for each month of the year) we load them
     # together and create a single dataset from them.  open_mfdataset also works if zarr_path
     # points to a specific zarr directory (with no wildcards).
+
+    # Silence the warning about large chunks.
+    # Alternatively, we could set this to True, but that slows down loading a Satellite batch
+    # from 8 seconds to 50 seconds!
+    dask.config.set(**{"array.slicing.split_large_chunks": False})
+
+    # Open datasets.
     dataset = xr.open_mfdataset(
         zarr_path,
         chunks="auto",  # See issue #456 for why we use "auto".
         mode="r",
         engine="zarr",
         concat_dim="time",
-        preprocess=remove_acq_time_from_dataset,
+        preprocess=remove_acq_time_from_dataset_and_fix_time_coords,
         consolidated=consolidated,
         combine="nested",
     )
 
     data_array = dataset["stacked_eumetsat_data"]
     del dataset
+
     # Flip coordinates to top-left first
     data_array = data_array.reindex(x=data_array.x[::-1])
 
-    # Sanity checks.
-    # If there are any duplicated init_times then drop the duplicated init_times:
+    # Sanity check!
     times = pd.DatetimeIndex(data_array["time"])
-    if not times.is_unique:
-        n_duplicates = times.duplicated().sum()
-        _LOG.warning(f"Satellite Zarr has {n_duplicates:,d} duplicated times.  Fixing...")
-        data_array = data_array.drop_duplicates(dim="time")
-        times = pd.DatetimeIndex(data_array["time"])
-
-    # If any init_times are not monotonic_increasing then drop the out-of-order init_times:
-    if not times.is_monotonic_increasing:
-        total_n_out_of_order_times = 0
-        _LOG.warning("Satellite Zarr times is not monotonic_increasing.  Fixing...")
-        while not times.is_monotonic_increasing:
-            diff = np.diff(times.view(int))
-            out_of_order = np.where(diff < 0)[0]
-            total_n_out_of_order_times += len(out_of_order)
-            out_of_order = times[out_of_order]
-            data_array = data_array.drop_sel(time=out_of_order)
-            times = pd.DatetimeIndex(data_array["init_time"])
-        _LOG.info(f"Fixed {total_n_out_of_order_times:,d} out of order init_times.")
-
     assert times.is_unique
     assert times.is_monotonic_increasing
 
